@@ -8,10 +8,10 @@
    Description :
 -------------------------------------------------
 """
-import logging
 
 from snippets.utils import *
 from snippets.decorators import *
 
+__version__ = "0.0.11"
 logging.basicConfig(level=logging.INFO, format="%(asctime)s [%(levelname)s][%(filename)s:%(lineno)d]:%(message)s",
                     datefmt='%Y-%m-%d %H:%M:%S')
